@@ -18,6 +18,10 @@
  *
  */
 
+#include <glib-object.h>
+
+#include <libdmapsharing/dmap-connection.h>
+
 #ifndef _DMAP_CONNECTION_PRIVATE_H
 #define _DMAP_CONNECTION_PRIVATE_H
 
@@ -27,4 +31,6 @@ gboolean dmap_connection_get (DmapConnection * self,
                               DmapResponseHandler handler,
                               gpointer user_data);
 
+void dmap_connection_setup (DmapConnection * connection);
+
 #endif
