@@ -32,6 +32,7 @@
 
 #include "dmap-md5.h"
 #include "dmap-connection.h"
+#include "dmap-error.h"
 #include "dmap-record-factory.h"
 #include "dmap-marshal.h"
 #include "dmap-structure.h"
@@ -110,6 +111,7 @@ enum
 	CONNECTED,
 	DISCONNECTED,
 	OPERATION_DONE,
+	ERROR,
 	LAST_SIGNAL
 };
 
@@ -121,7 +123,7 @@ _dispose (GObject * object)
 	DmapConnectionPrivate *priv = DMAP_CONNECTION (object)->priv;
 	GSList *l;
 
-	g_debug ("DAAP connection dispose");
+	g_debug ("DMAP connection dispose");
 
 	if (priv->emit_progress_id != 0) {
 		g_source_remove (priv->emit_progress_id);
@@ -468,6 +470,13 @@ dmap_connection_class_init (DmapConnectionClass * klass)
 			      G_STRUCT_OFFSET (DmapConnectionClass,
 					       operation_done), NULL, NULL,
 			      g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
+	_signals[ERROR] =
+		g_signal_new ("error",
+		              G_TYPE_FROM_CLASS (object_class),
+		              G_SIGNAL_RUN_FIRST,
+		              0, NULL, NULL,
+		              g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1,
+		              G_TYPE_POINTER);
 }
 
 static void
@@ -592,15 +601,14 @@ _connection_set_error_message (DmapConnection * connection,
 	}
 }
 
-typedef struct
-{
+typedef struct {
 	SoupMessage *message;
 	int status;
 	DmapConnection *connection;
 
 	DmapResponseHandler response_handler;
 	gpointer user_data;
-} DAAPResponseData;
+} DmapResponseData;
 
 static gboolean
 _emit_progress_idle (DmapConnection * connection)
@@ -616,7 +624,7 @@ _emit_progress_idle (DmapConnection * connection)
 }
 
 static void
-_actual_http_response_handler (DAAPResponseData * data)
+_actual_http_response_handler (DmapResponseData * data)
 {
 	DmapConnectionPrivate *priv;
 	GNode *structure;
@@ -742,6 +750,7 @@ _actual_http_response_handler (DAAPResponseData * data)
 		_connection_set_error_message (data->connection,
 					      ("libdmapsharing is not able to connect to iTunes 7 shares"));
 	} else if (SOUP_STATUS_IS_SUCCESSFUL (data->status)) {
+		GError *error = NULL;
 		DmapStructureItem *item;
 
 		if ( /* FIXME: !rb_is_main_thread () */ TRUE) {
@@ -753,12 +762,13 @@ _actual_http_response_handler (DAAPResponseData * data)
 				g_idle_add ((GSourceFunc) _emit_progress_idle,
 					    data->connection);
 		}
-		structure = dmap_structure_parse (response, response_length);
+		structure = dmap_structure_parse (response, response_length, &error);
 		if (structure == NULL) {
-			g_debug ("No daap structure returned from %s",
-				 message_path);
-
+			dmap_connection_emit_error(data->connection, error->code,
+			                          "Error parsing %s response: %s\n", message_path,
+			                           error->message);
 			data->status = SOUP_STATUS_MALFORMED;
+			g_clear_error(&error);
 		} else {
 			int dmap_status = 0;
 
@@ -811,7 +821,7 @@ _actual_http_response_handler (DAAPResponseData * data)
 
 static void
 _http_response_handler (SoupSession * session,
-                        SoupMessage * message, DAAPResponseData * data)
+                        SoupMessage * message, DmapResponseData * data)
 {
 	int response_length;
 
@@ -859,7 +869,7 @@ _http_get (DmapConnection * connection,
 {
 	gboolean ok = FALSE;
 	DmapConnectionPrivate *priv = connection->priv;
-	DAAPResponseData *data;
+	DmapResponseData *data;
 	SoupMessage *message;
 
 	message = _build_message (connection, path, need_hash,
@@ -872,7 +882,7 @@ _http_get (DmapConnection * connection,
 
 	priv->use_response_handler_thread = use_thread;
 
-	data = g_new0 (DAAPResponseData, 1);
+	data = g_new0 (DmapResponseData, 1);
 	data->response_handler = handler;
 	data->user_data = user_data;
 
@@ -1180,6 +1190,7 @@ _handle_song_listing (DmapConnection * connection,
 			 &item_id);
 
 		if (record) {
+			GError *error = NULL;
 			gchar *uri = NULL;
 			gchar *format = NULL;
 
@@ -1206,7 +1217,10 @@ _handle_song_listing (DmapConnection * connection,
 			/*} */
 
 			g_object_set (record, "location", uri, NULL);
-			dmap_db_add (connection->priv->db, record);
+			dmap_db_add (connection->priv->db, record, &error);
+			if (NULL != error) {
+				g_signal_emit (connection, _signals[ERROR], 0, error);
+			}
 			g_object_unref (record);
 			g_hash_table_insert (connection->priv->item_id_to_uri,
 					     GINT_TO_POINTER (item_id),
@@ -1397,7 +1411,7 @@ _finish (DmapConnection * connection)
 {
 	g_assert(IS_DMAP_CONNECTION (connection));
 
-	g_debug ("DAAP finish");
+	g_debug ("DMAP finish");
 	connection->priv->state = DMAP_DONE;
 	connection->priv->progress = 1.0f;
 
@@ -1419,29 +1433,29 @@ _do_something (DmapConnection * connection)
 
 	switch (priv->state) {
 	case DMAP_GET_INFO:
-		g_debug ("Getting DAAP server info");
+		g_debug ("Getting DMAP server info");
 		if (!_http_get
 		    (connection, "/server-info", FALSE, 0.0, 0, FALSE,
 		     (DmapResponseHandler) _handle_server_info, NULL, FALSE)) {
-			g_debug ("Could not get DAAP connection info");
+			g_debug ("Could not get DMAP connection info");
 			_state_done (connection, FALSE);
 		}
 		break;
 
 	case DMAP_LOGIN:
 		// NOTE: libsoup will signal if password required and not present.
-		g_debug ("Logging into DAAP server");
+		g_debug ("Logging into DMAP server");
 		if (!_http_get (connection, "/login", FALSE, 0.0, 0, FALSE,
 			       (DmapResponseHandler) _handle_login, NULL,
 			       FALSE)) {
-			g_debug ("Could not login to DAAP server");
+			g_debug ("Could not login to DMAP server");
 			_state_done (connection, FALSE);
 		}
 
 		break;
 
 	case DMAP_GET_REVISION_NUMBER:
-		g_debug ("Getting DAAP server database revision number");
+		g_debug ("Getting DMAP server database revision number");
 		path = g_strdup_printf
 			("/update?session-id=%u&revision-number=1",
 			 priv->session_id);
@@ -1455,7 +1469,7 @@ _do_something (DmapConnection * connection)
 		break;
 
 	case DMAP_GET_DB_INFO:
-		g_debug ("Getting DAAP database info");
+		g_debug ("Getting DMAP database info");
 		path = g_strdup_printf
 			("/databases?session-id=%u&revision-number=%d",
 			 priv->session_id, priv->revision_number);
@@ -1463,14 +1477,14 @@ _do_something (DmapConnection * connection)
 		    (connection, path, TRUE, priv->dmap_version, 0, FALSE,
 		     (DmapResponseHandler) _handle_database_info, NULL,
 		     FALSE)) {
-			g_debug ("Could not get DAAP database info");
+			g_debug ("Could not get DMAP database info");
 			_state_done (connection, FALSE);
 		}
 		g_free (path);
 		break;
 
-	case DMAP_GET_SONGS:
-		g_debug ("Getting DAAP song listing");
+	case DMAP_GET_MEDIA:
+		g_debug ("Getting DMAP song listing");
 		meta = DMAP_CONNECTION_GET_CLASS
 			(connection)->get_query_metadata (connection);
 		path = g_strdup_printf
@@ -1480,7 +1494,7 @@ _do_something (DmapConnection * connection)
 		if (!_http_get
 		    (connection, path, TRUE, priv->dmap_version, 0, FALSE,
 		     (DmapResponseHandler) _handle_song_listing, NULL, TRUE)) {
-			g_debug ("Could not get DAAP song listing");
+			g_debug ("Could not get DMAP song listing");
 			_state_done (connection, FALSE);
 		}
 		g_free (path);
@@ -1488,7 +1502,7 @@ _do_something (DmapConnection * connection)
 		break;
 
 	case DMAP_GET_PLAYLISTS:
-		g_debug ("Getting DAAP playlists");
+		g_debug ("Getting DMAP playlists");
 		path = g_strdup_printf
 			("/databases/%d/containers?session-id=%u&revision-number=%d",
 			 priv->database_id, priv->session_id,
@@ -1496,7 +1510,7 @@ _do_something (DmapConnection * connection)
 		if (!_http_get
 		    (connection, path, TRUE, priv->dmap_version, 0, FALSE,
 		     (DmapResponseHandler) _handle_playlists, NULL, TRUE)) {
-			g_debug ("Could not get DAAP playlists");
+			g_debug ("Could not get DMAP playlists");
 			_state_done (connection, FALSE);
 		}
 		g_free (path);
@@ -1510,7 +1524,7 @@ _do_something (DmapConnection * connection)
 						  priv->reading_playlist);
 
 			g_assert (playlist);
-			g_debug ("Reading DAAP playlist %d entries",
+			g_debug ("Reading DMAP playlist %d entries",
 				 priv->reading_playlist);
 			path = g_strdup_printf
 				("/databases/%d/containers/%d/items?session-id=%u&revision-number=%d&meta=dmap.itemid",
@@ -1521,7 +1535,7 @@ _do_something (DmapConnection * connection)
 			     FALSE,
 			     (DmapResponseHandler) _handle_playlist_entries,
 			     NULL, TRUE)) {
-				g_debug ("Could not get entries for DAAP playlist %d", priv->reading_playlist);
+				g_debug ("Could not get entries for DMAP playlist %d", priv->reading_playlist);
 				_state_done (connection,
 							    FALSE);
 			}
@@ -1530,13 +1544,13 @@ _do_something (DmapConnection * connection)
 		break;
 
 	case DMAP_LOGOUT:
-		g_debug ("Logging out of DAAP server");
+		g_debug ("Logging out of DMAP server");
 		path = g_strdup_printf ("/logout?session-id=%u",
 					priv->session_id);
 		if (!_http_get
 		    (connection, path, TRUE, priv->dmap_version, 0, FALSE,
 		     (DmapResponseHandler) _handle_logout, NULL, FALSE)) {
-			g_debug ("Could not log out of DAAP server");
+			g_debug ("Could not log out of DMAP server");
 			_state_done (connection, FALSE);
 		}
 
@@ -1544,7 +1558,7 @@ _do_something (DmapConnection * connection)
 		break;
 
 	case DMAP_DONE:
-		g_debug ("DAAP done");
+		g_debug ("DMAP done");
 
 		_finish (connection);
 
@@ -1562,8 +1576,7 @@ dmap_connection_is_connected (DmapConnection * connection)
 	return connection->priv->is_connected;
 }
 
-typedef struct
-{
+typedef struct {
 	DmapConnection *connection;
 	DmapConnectionFunc callback;
 	gpointer user_data;
@@ -1593,7 +1606,7 @@ _connected_cb (DmapConnection * connection, ConnectionResponseData * rdata)
 					      rdata);
 
 	/* if connected then we succeeded */
-	result = dmap_connection_is_connected (connection);
+	result = connection->priv->is_connected;
 
 	if (rdata->callback) {
 		rdata->callback (rdata->connection,
@@ -1664,7 +1677,7 @@ dmap_connection_setup (DmapConnection * connection)
 }
 
 // FIXME: it would be nice if this mirrored the use of DmapMdnsBrowser. That is, connect callback handler to a signal.
-// This would allow Vala to associated a lambda function with the signal.
+// This would allow Vala to associate a lambda function with the signal.
 void
 dmap_connection_start (DmapConnection * connection,
                        DmapConnectionFunc callback, gpointer user_data)
@@ -1674,18 +1687,11 @@ dmap_connection_start (DmapConnection * connection,
 	g_assert(IS_DMAP_CONNECTION (connection));
 	g_assert(connection->priv->state == DMAP_GET_INFO);
 
-	g_debug ("Creating new DAAP connection to %s:%d",
+	g_debug ("Creating new DMAP connection to %s:%d",
 		 connection->priv->host, connection->priv->port);
 
 	dmap_connection_setup (connection);
 
-	if (connection->priv->base_uri == NULL) {
-		g_debug ("Error parsing http://%s:%d", connection->priv->host,
-			 connection->priv->port);
-		/* FIXME: do callback */
-		return;
-	}
-
 	connection->priv->daap_base_uri =
 		g_strdup_printf ("daap://%s:%d", connection->priv->host,
 				 connection->priv->port);
@@ -1719,7 +1725,7 @@ _disconnected_cb (DmapConnection * connection, ConnectionResponseData * rdata)
 					      rdata);
 
 	/* if not connected then we succeeded */
-	result = !dmap_connection_is_connected (connection);
+	result = !connection->priv->is_connected;
 
 	if (rdata->callback) {
 		rdata->callback (rdata->connection,
@@ -1734,9 +1740,9 @@ _disconnected_cb (DmapConnection * connection, ConnectionResponseData * rdata)
 }
 
 void
-dmap_connection_disconnect (DmapConnection * connection,
-			    DmapConnectionFunc callback,
-			    gpointer user_data)
+dmap_connection_stop(DmapConnection * connection,
+                     DmapConnectionFunc callback,
+                     gpointer user_data)
 {
 	DmapConnectionPrivate *priv = connection->priv;
 	ConnectionResponseData *rdata;
@@ -1825,3 +1831,87 @@ dmap_connection_get_playlists (DmapConnection * connection)
 {
 	return connection->priv->playlists;
 }
+
+void
+dmap_connection_emit_error(DmapConnection *connection, gint code,
+                           const gchar *format, ...)
+{
+	va_list ap;
+	GError *error;
+
+	va_start(ap, format);
+	error = g_error_new_valist(DMAP_ERROR, code, format, ap);
+	g_signal_emit_by_name(connection, "error", error);
+
+	va_end(ap);
+}
+
+#ifdef HAVE_CHECK
+
+#include <check.h>
+#include <libdmapsharing/dmap-av-connection.h>
+
+static int _status = DMAP_STATUS_OK;
+
+static void
+_error_cb(DmapConnection *share, GError *error, gpointer user_data)
+{
+	_status = error->code;
+}
+
+#define _ACTUAL_HTTP_RESPONSE_HANDLER_TEST(bytes, size, __status) \
+{ \
+	SoupMessage      *message; \
+	DmapConnection   *connection; \
+	char              body[] = bytes; \
+	DmapResponseData *data; \
+	\
+	_status = DMAP_STATUS_OK; \
+	\
+	message = soup_message_new(SOUP_METHOD_GET, "http://test/"); \
+	soup_message_set_response(message, \
+	                         "application/x-dmap-tagged", \
+	                          SOUP_MEMORY_STATIC, \
+	                          body, \
+	                          sizeof body); \
+	soup_message_set_status(message, SOUP_STATUS_OK); \
+	\
+	connection = g_object_new(DMAP_TYPE_AV_CONNECTION, NULL); \
+	g_signal_connect(connection, "error", G_CALLBACK(_error_cb), NULL); \
+	\
+	data = g_new0(DmapResponseData, 1); \
+	data->message    = message; \
+	data->status     = SOUP_STATUS_OK; \
+	data->connection = connection; \
+	\
+	_actual_http_response_handler(data); \
+	\
+	ck_assert(_status == __status); \
+} \
+
+START_TEST(_actual_http_response_handler_test) \
+_ACTUAL_HTTP_RESPONSE_HANDLER_TEST("minm\x00\x00\x00\x0dHello, world!",
+                                    sizeof bytes, DMAP_STATUS_OK);
+END_TEST
+
+/* Length < 8 only allowed for DMAP_RAW. */
+START_TEST(_actual_http_response_handler_too_short_test) \
+_ACTUAL_HTTP_RESPONSE_HANDLER_TEST("xxxx", sizeof bytes,
+                                    DMAP_STATUS_RESPONSE_TOO_SHORT);
+END_TEST
+
+START_TEST(_actual_http_response_handler_bad_cc_test) \
+_ACTUAL_HTTP_RESPONSE_HANDLER_TEST("xxxx\x00\x00\x00\x00", sizeof bytes,
+                                    DMAP_STATUS_INVALID_CONTENT_CODE);
+END_TEST
+
+/* Length of 99 is larger than sizeof containing array. */
+START_TEST(_actual_http_response_handler_bad_len_test) \
+_ACTUAL_HTTP_RESPONSE_HANDLER_TEST("minm\x00\x00\x00\x99Hello, world!",
+                                    sizeof bytes,
+                                    DMAP_STATUS_INVALID_CONTENT_CODE_SIZE);
+END_TEST
+
+#include "dmap-connection-suite.c"
+
+#endif
