@@ -31,8 +31,7 @@
 
 G_BEGIN_DECLS
 
-typedef struct
-{
+typedef struct {
 	char *name;
 	int id;
 	GList *uris;
@@ -88,27 +87,38 @@ typedef struct
 
 typedef struct DmapConnectionPrivate DmapConnectionPrivate;
 
-typedef enum
-{
+/**
+ * DmapConnectionState:
+ * @DMAP_GET_INFO: getting DMAP server information
+ * @DMAP_LOGIN: logging in to DMAP server
+ * @DMAP_GET_REVISION_NUMBER: getting server's database revision number
+ * @DMAP_GET_DB_INFO: getting DMAP database information
+ * @DMAP_GET_MEDIA: getting DMAP media listing
+ * @DMAP_GET_PLAYLISTS: getting DMAP playlists
+ * @DMAP_GET_PLAYLIST_ENTRIES: getting entries in playlist
+ * @DMAP_LOGOUT: logging out of DMAP server
+ * @DMAP_DONE: done
+ *
+ * Enumeration of connection states.
+ */
+typedef enum {
 	DMAP_GET_INFO = 0,
 	DMAP_LOGIN,
 	DMAP_GET_REVISION_NUMBER,
 	DMAP_GET_DB_INFO,
-	DMAP_GET_SONGS,
+	DMAP_GET_MEDIA,
 	DMAP_GET_PLAYLISTS,
 	DMAP_GET_PLAYLIST_ENTRIES,
 	DMAP_LOGOUT,
 	DMAP_DONE
 } DmapConnectionState;
 
-typedef struct
-{
+typedef struct {
 	GObject parent;
 	DmapConnectionPrivate *priv;
 } DmapConnection;
 
-typedef struct
-{
+typedef struct {
 	GObjectClass parent;
 
 	/* Pure virtual methods: */
@@ -119,12 +129,12 @@ typedef struct
 				    DmapRecordFactory * factory, GNode * mlcl,
 				    gint * item_id);
 
-	SoupMessage *(*build_message)
-	 
-		(DmapConnection * connection,
-	   const gchar * path,
-	   gboolean need_hash,
-	   gdouble version, gint req_id, gboolean send_close);
+	SoupMessage *(*build_message) (DmapConnection * connection,
+	                               const gchar * path,
+	                               gboolean need_hash,
+	                               gdouble version,
+	                               gint req_id,
+	                               gboolean send_close);
 	void (*connected) (DmapConnection * connection);
 	void (*disconnected) (DmapConnection * connection);
 
@@ -148,8 +158,13 @@ typedef void (*DmapResponseHandler) (DmapConnection * connection,
 
 GType dmap_connection_get_type (void);
 
+/**
+ * dmap_connection_is_connected:
+ * @connection: The connection.
+ *
+ * Returns TRUE if the connection is presently connected.
+ */
 gboolean dmap_connection_is_connected (DmapConnection * connection);
-void dmap_connection_setup (DmapConnection * connection);
 
 /**
  * dmap_connection_start:
@@ -164,16 +179,16 @@ void dmap_connection_start (DmapConnection * connection,
 			    gpointer user_data);
 
 /**
- * dmap_connection_disconnect:
+ * dmap_connection_stop:
  * @connection: The connection.
  * @callback: (scope async): The function to call once the connection is complete.
  * @user_data: The data to pass to the callback.
  *
  * Disconnect from the remote DMAP share.
  */
-void dmap_connection_disconnect (DmapConnection * connection,
-				 DmapConnectionFunc callback,
-				 gpointer user_data);
+void dmap_connection_stop(DmapConnection * connection,
+                          DmapConnectionFunc callback,
+                          gpointer user_data);
 
 SoupMessageHeaders *dmap_connection_get_headers (DmapConnection * connection,
 						 const char *uri);
@@ -208,5 +223,15 @@ void dmap_connection_authenticate_message (DmapConnection *connection,
 					   SoupAuth *auth,
 					   const char *password);
 
+/**
+ * dmap_connection_emit_error:
+ * @connection: a #DmapConnection instance.
+ * @code: error code.
+ * @format: printf()-style format for error message
+ * @...: parameters for message format
+ */
+void dmap_connection_emit_error(DmapConnection *connection, gint code,
+                                const gchar *format, ...);
+
 G_END_DECLS
 #endif /* _DMAP_CONNECTION_H */
