@@ -79,8 +79,7 @@ struct DmapControlSharePrivate
 /*
  * Internal representation of a DACP remote.
  */
-typedef struct
-{
+typedef struct {
 	gchar *host;
 	guint port;
 	gchar *pair_txt;
@@ -89,15 +88,13 @@ typedef struct
 
 #define DMAP_CONTROL_SHARE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_CONTROL_SHARE, DmapControlSharePrivate))
 
-enum
-{
+enum {
 	PROP_0,
 	PROP_LIBRARY_NAME,
 	PROP_PLAYER
 };
 
-enum
-{
+enum {
 	REMOTE_FOUND,
 	REMOTE_LOST,
 	REMOTE_PAIRED,
@@ -454,16 +451,10 @@ dmap_control_share_new (const gchar *library_name,
 	                                        "transcode-mimetype", NULL, NULL));
 }
 
-void
-dmap_control_share_start_lookup (DmapControlShare * share)
+gboolean
+dmap_control_share_start_lookup (DmapControlShare * share, GError **error)
 {
-	gboolean ok;
-	GError *error;
-
-	if (share->priv->mdns_browser) {
-		g_warning ("DACP browsing already started");
-		return;
-	}
+	g_assert(NULL == share->priv->mdns_browser);
 
 	share->priv->mdns_browser =
 		dmap_mdns_browser_new (DMAP_MDNS_SERVICE_TYPE_DACP);
@@ -475,13 +466,7 @@ dmap_control_share_start_lookup (DmapControlShare * share)
 				 "service-removed",
 				 G_CALLBACK (_mdns_remote_removed), share, 0);
 
-	error = NULL;
-	ok = dmap_mdns_browser_start (share->priv->mdns_browser, &error);
-	if (!ok) {
-		g_warning ("Unable to start Remote lookup: %s",
-			   error->message);
-		g_error_free (error);
-	}
+	return dmap_mdns_browser_start (share->priv->mdns_browser, error);
 }
 
 static gboolean
@@ -493,30 +478,28 @@ _remove_remotes_cb (gpointer service_name, gpointer remote_info,
 	return TRUE;
 }
 
-void
-dmap_control_share_stop_lookup (DmapControlShare * share)
+gboolean
+dmap_control_share_stop_lookup (DmapControlShare * share, GError **error)
 {
-	gboolean ok;
-	GError *error;
+	gboolean ok = FALSE;
 
-	if (!share->priv->mdns_browser) {
-		g_warning ("DACP browsing not started");
-		return;
-	}
+	g_assert(NULL != share->priv->mdns_browser);
 
 	g_hash_table_foreach_remove (share->priv->remotes,	
                                      _remove_remotes_cb,
 	                             share);
 
-	error = NULL;
-	ok = dmap_mdns_browser_stop (share->priv->mdns_browser, &error);
+	ok = dmap_mdns_browser_stop (share->priv->mdns_browser, error);
 	if (!ok) {
-		g_warning ("Unable to stop Remote lookup: %s",
-			   error->message);
-		g_error_free (error);
+		goto done;
 	}
 
 	share->priv->mdns_browser = NULL;
+
+	ok = TRUE;
+
+done:
+	return ok;
 }
 
 static void
@@ -538,7 +521,7 @@ _fill_playstatusupdate (DmapControlShare * share, SoupMessage * message)
 	record = dmap_control_player_now_playing_record (share->priv->player);
 
 	cmst = dmap_structure_add (NULL, DMAP_CC_CMST);
-	dmap_structure_add (cmst, DMAP_CC_MSTT, (gint32) DMAP_STATUS_OK);
+	dmap_structure_add (cmst, DMAP_CC_MSTT, (gint32) SOUP_STATUS_OK);
 	dmap_structure_add (cmst, DMAP_CC_CMSR,
 			    share->priv->current_revision);
 	dmap_structure_add (cmst, DMAP_CC_CAVC, 1);
@@ -656,7 +639,7 @@ dmap_control_share_login (DmapShare * share,
 			       &allow_login);
 
 		if (!allow_login) {
-			g_debug ("Unknown remote trying to connect");
+			g_warning("Unknown remote trying to connect");
 			soup_message_set_status (message,
 						 SOUP_STATUS_FORBIDDEN);
 			return;
@@ -719,7 +702,7 @@ dmap_control_share_ctrl_int (DmapShare * share,
 		caci = dmap_structure_add (NULL, DMAP_CC_CACI);
 		// dmap.status
 		dmap_structure_add (caci, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		// dmap.updatetype
 		dmap_structure_add (caci, DMAP_CC_MUTY, 0);
 		// dmap.specifiedtotalcount
@@ -765,7 +748,7 @@ dmap_control_share_ctrl_int (DmapShare * share,
 		}
 
 		cmgt = dmap_structure_add (NULL, DMAP_CC_CMGT);
-		dmap_structure_add (cmgt, DMAP_CC_MSTT, DMAP_STATUS_OK);
+		dmap_structure_add (cmgt, DMAP_CC_MSTT, SOUP_STATUS_OK);
 
 		properties = g_strsplit (properties_query, ",", -1);
 		for (property = properties; *property; property++) {
@@ -803,7 +786,7 @@ dmap_control_share_ctrl_int (DmapShare * share,
 
 		casp = dmap_structure_add (NULL, DMAP_CC_CASP);
 		dmap_structure_add (casp, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (casp, DMAP_CC_MDCL);
 
 		dmap_structure_add (casp, DMAP_CC_CAIA, TRUE);
@@ -962,7 +945,7 @@ dmap_control_share_ctrl_int (DmapShare * share,
 
 			cacr = dmap_structure_add (NULL, DMAP_CC_CACR);
 			dmap_structure_add (cacr, DMAP_CC_MSTT,
-					    DMAP_STATUS_OK);
+					    SOUP_STATUS_OK);
 			dmap_structure_add (cacr, DMAP_CC_MIID, index);
 
 			dmap_share_message_set_from_dmap_structure (share,
