@@ -38,14 +38,10 @@ struct DmapGstMP3InputStreamPrivate
 	GstElement *sink;
 };
 
-/* FIXME: See note in dmap-gst-input-stream.h */
-void dmap_gst_input_stream_new_buffer_cb (GstElement * element,
-					  DmapGstInputStream * stream);
-
 static void
-pad_added_cb (GstElement * element,
-              GstPad * pad,
-              GstElement *convert)
+_pad_added_cb (GstElement * element,
+               GstPad * pad,
+               GstElement *convert)
 {
 	/* Link remaining pad after decodebin2 does its magic. */
 	GstPad *conv_pad;
@@ -53,7 +49,7 @@ pad_added_cb (GstElement * element,
 	conv_pad = gst_element_get_static_pad (convert, "sink");
 	g_assert (conv_pad != NULL);
 
-	if (pads_compatible (pad, conv_pad)) {
+	if (gst_util_pads_compatible (pad, conv_pad)) {
 		g_assert (!GST_PAD_IS_LINKED
 			  (gst_element_get_static_pad
 			   (convert, "sink")));
@@ -140,7 +136,7 @@ dmap_gst_mp3_input_stream_new (GInputStream * src_stream)
 	gst_app_sink_set_max_buffers (GST_APP_SINK (sink), GST_APP_MAX_BUFFERS);
 	gst_app_sink_set_drop (GST_APP_SINK (sink), FALSE);
 
-	g_signal_connect (decode, "pad-added", G_CALLBACK (pad_added_cb), convert);
+	g_signal_connect (decode, "pad-added", G_CALLBACK (_pad_added_cb), convert);
 
 	/* FIXME: this technique is shared with dmapd-dmap-av-share.c */
 	sret = gst_element_set_state (pipeline, GST_STATE_PLAYING);
@@ -199,7 +195,7 @@ done:
 }
 
 static void
-dmap_gst_mp3_input_stream_kill_pipeline (DmapGstInputStream * stream)
+_kill_pipeline (DmapGstInputStream * stream)
 {
 	DmapGstMP3InputStream *mp3_stream =
 		DMAP_GST_MP3_INPUT_STREAM (stream);
@@ -220,7 +216,7 @@ dmap_gst_mp3_input_stream_class_init (DmapGstMP3InputStreamClass * klass)
 	g_type_class_add_private (klass,
 				  sizeof (DmapGstMP3InputStreamPrivate));
 
-	parent_class->kill_pipeline = dmap_gst_mp3_input_stream_kill_pipeline;
+	parent_class->kill_pipeline = _kill_pipeline;
 }
 
 static void
