@@ -20,8 +20,8 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
-#ifndef _DMAP_GST_MP3_INPUT_STREAM
-#define _DMAP_GST_MP3_INPUT_STREAM
+#ifndef _DMAP_GST_MP3_INPUT_STREAM_H
+#define _DMAP_GST_MP3_INPUT_STREAM_H
 
 #include <gio/gio.h>
 
@@ -47,14 +47,12 @@ G_BEGIN_DECLS
 					   DmapGstMP3InputStreamPrivate))
 typedef struct DmapGstMP3InputStreamPrivate DmapGstMP3InputStreamPrivate;
 
-typedef struct
-{
+typedef struct {
 	DmapGstInputStream parent;
 	DmapGstMP3InputStreamPrivate *priv;
 } DmapGstMP3InputStream;
 
-typedef struct
-{
+typedef struct {
 	DmapGstInputStreamClass parent;
 } DmapGstMP3InputStreamClass;
 
@@ -63,4 +61,4 @@ GType dmap_gst_mp3_input_stream_get_type (void);
 GInputStream *dmap_gst_mp3_input_stream_new (GInputStream * stream);
 
 G_END_DECLS
-#endif /* _DMAP_GST_MP3_INPUT_STREAM */
+#endif
