@@ -40,7 +40,7 @@
 
 static void dmap_mdns_publisher_class_init (DmapMdnsPublisherClass * klass);
 static void dmap_mdns_publisher_init (DmapMdnsPublisher * publisher);
-static void dmap_mdns_publisher_finalize (GObject * object);
+static void _finalize (GObject * object);
 
 #define DMAP_MDNS_PUBLISHER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), DMAP_TYPE_MDNS_PUBLISHER, DmapMdnsPublisherPrivate))
 
@@ -67,11 +67,11 @@ enum
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL] = { 0, };
+static guint _signals[LAST_SIGNAL] = { 0, };
 
 G_DEFINE_TYPE (DmapMdnsPublisher, dmap_mdns_publisher, G_TYPE_OBJECT);
 
-static gpointer publisher_object = NULL;
+static gpointer _publisher_object = NULL;
 
 GQuark
 dmap_mdns_publisher_error_quark (void)
@@ -86,34 +86,35 @@ dmap_mdns_publisher_error_quark (void)
 }
 
 static void
-emit_published (char *name, DmapMdnsPublisher * publisher)
+_emit_published (char *name, DmapMdnsPublisher * publisher)
 {
-	g_signal_emit (publisher, signals[PUBLISHED], 0, name);
+	g_signal_emit (publisher, _signals[PUBLISHED], 0, name);
 }
 
 static void
-entry_group_cb (AvahiEntryGroup * group,
-		AvahiEntryGroupState state, DmapMdnsPublisher * publisher)
+_entry_group_cb (AvahiEntryGroup * group,
+                 AvahiEntryGroupState state, DmapMdnsPublisher * publisher)
 {
 	if (state == AVAHI_ENTRY_GROUP_ESTABLISHED) {
 		g_slist_foreach (publisher->priv->service,
-				 (GFunc) emit_published, publisher);
+				 (GFunc) _emit_published, publisher);
 	} else if (state == AVAHI_ENTRY_GROUP_COLLISION) {
 		g_warning ("MDNS name collision");
 
 		/* FIXME: how to know which name collided?
-		 * g_signal_emit (publisher, signals [NAME_COLLISION], 0, publisher->priv->name);
+		 * g_signal_emit (publisher, _signals [NAME_COLLISION], 0, publisher->priv->name);
 		 */
-		g_signal_emit (publisher, signals[NAME_COLLISION], 0,
+		g_signal_emit (publisher, _signals[NAME_COLLISION], 0,
 			       "unknown");
 	}
 }
 
 static gboolean
-create_service (struct DmapMdnsPublisherService *service,
-		DmapMdnsPublisher * publisher, GError ** error)
+_create_service (struct DmapMdnsPublisherService *service,
+                 DmapMdnsPublisher * publisher, GError ** error)
 {
 	int ret;
+	gboolean ok = FALSE;
 	const char *password_record;
 	AvahiStringList *txt_records;
 
@@ -156,15 +157,19 @@ create_service (struct DmapMdnsPublisherService *service,
 			     "%s: %s",
 			     _("Could not add service"),
 			     avahi_strerror (ret));
-		return FALSE;
+		goto done;
 	}
 
-	return TRUE;
+	ok = TRUE;
+
+done:
+	return ok;
 }
 
 static gboolean
-create_services (DmapMdnsPublisher * publisher, GError ** error)
+_create_services (DmapMdnsPublisher * publisher, GError ** error)
 {
+	gboolean ok = FALSE;
 	static int suffix = 0;
 	gchar *name;
 	GSList *ptr1, *ptr2;
@@ -175,7 +180,7 @@ create_services (DmapMdnsPublisher * publisher, GError ** error)
 		publisher->priv->entry_group =
 			avahi_entry_group_new (publisher->priv->client,
 					       (AvahiEntryGroupCallback)
-					       entry_group_cb, publisher);
+					       _entry_group_cb, publisher);
 
 		if (publisher->priv->entry_group == NULL) {
 			g_debug ("Could not create AvahiEntryGroup for publishing");
@@ -185,7 +190,7 @@ create_services (DmapMdnsPublisher * publisher, GError ** error)
 				     "%s",
 				     _
 				     ("Could not create AvahiEntryGroup for publishing"));
-			return FALSE;
+			goto done;
 		}
 
 		dmap_mdns_avahi_set_entry_group (publisher->
@@ -210,10 +215,10 @@ create_services (DmapMdnsPublisher * publisher, GError ** error)
 		if (strcmp(name, service1->name)) {
 			g_free(service1->name);
 			service1->name = name;
-			g_signal_emit (publisher, signals[NAME_COLLISION], 0, name);
+			g_signal_emit (publisher, _signals[NAME_COLLISION], 0, name);
 		}
-		if (!create_service (service1, publisher, error)) {
-			return FALSE;
+		if (!_create_service (service1, publisher, error)) {
+			goto done;
 		}
 	}
 
@@ -226,27 +231,31 @@ create_services (DmapMdnsPublisher * publisher, GError ** error)
 			     "%s: %s",
 			     _("Could not commit service"),
 			     avahi_strerror (ret));
-		return FALSE;
+		goto done;
 	}
 
-	return TRUE;
+	ok = TRUE;
+
+done:
+	return ok;
 }
 
 static gboolean
-refresh_services (DmapMdnsPublisher * publisher, GError ** error)
+_refresh_services (DmapMdnsPublisher * publisher, GError ** error)
 {
-	return create_services (publisher, error);
+	return _create_services (publisher, error);
 }
 
 static struct DmapMdnsPublisherService *
-find_service_by_port (GSList * list, guint port)
+_find_service_by_port (GSList * list, guint port)
 {
 	GSList *ptr;
 
 	for (ptr = list; ptr; ptr = g_slist_next (ptr)) {
 		if (port ==
-		    ((struct DmapMdnsPublisherService *) ptr->data)->port)
+		    ((struct DmapMdnsPublisherService *) ptr->data)->port) {
 			break;
+		}
 	}
 
 	return ptr ? ptr->data : NULL;
@@ -261,7 +270,7 @@ dmap_mdns_publisher_rename_at_port (DmapMdnsPublisher * publisher,
 
 	g_return_val_if_fail (publisher != NULL, FALSE);
 
-	ptr = find_service_by_port (publisher->priv->service, port);
+	ptr = _find_service_by_port (publisher->priv->service, port);
 
 	if (ptr == NULL) {
 		g_set_error (error,
@@ -275,7 +284,7 @@ dmap_mdns_publisher_rename_at_port (DmapMdnsPublisher * publisher,
 	ptr->name = g_strdup (name);
 
 	if (publisher->priv->entry_group) {
-		refresh_services (publisher, error);
+		_refresh_services (publisher, error);
 	}
 
 	return TRUE;
@@ -311,11 +320,11 @@ dmap_mdns_publisher_publish (DmapMdnsPublisher * publisher,
 	publisher->priv->service =
 		g_slist_append (publisher->priv->service, service);
 
-	return create_services (publisher, error);
+	return _create_services (publisher, error);
 }
 
 static void
-free_service (struct DmapMdnsPublisherService *service, gpointer user_data)
+_free_service (struct DmapMdnsPublisherService *service, gpointer user_data)
 {
 	g_free (service->name);
 	g_free (service->type_of_service);
@@ -340,7 +349,7 @@ dmap_mdns_publisher_withdraw (DmapMdnsPublisher * publisher,
 
 	if (publisher->priv->entry_group == NULL
 	    || !(ptr =
-		 find_service_by_port (publisher->priv->service, port))) {
+		 _find_service_by_port (publisher->priv->service, port))) {
 		g_set_error (error, DMAP_MDNS_PUBLISHER_ERROR,
 			     DMAP_MDNS_PUBLISHER_ERROR_FAILED, "%s",
 			     _("The MDNS service is not published"));
@@ -349,14 +358,14 @@ dmap_mdns_publisher_withdraw (DmapMdnsPublisher * publisher,
 
 	publisher->priv->service =
 		g_slist_remove (publisher->priv->service, ptr);
-	free_service (ptr, NULL);
+	_free_service (ptr, NULL);
 
 	if (publisher->priv->service == NULL) {
 		avahi_entry_group_reset (publisher->priv->entry_group);
 		avahi_entry_group_free (publisher->priv->entry_group);
 		publisher->priv->entry_group = NULL;
 	} else {
-		create_services (publisher, error);
+		_create_services (publisher, error);
 		if (error != NULL)
 			return FALSE;
 	}
@@ -365,9 +374,8 @@ dmap_mdns_publisher_withdraw (DmapMdnsPublisher * publisher,
 }
 
 static void
-dmap_mdns_publisher_set_property (GObject * object,
-				  guint prop_id,
-				  const GValue * value, GParamSpec * pspec)
+_set_property (GObject * object, guint prop_id, const GValue * value,
+               GParamSpec * pspec)
 {
 	switch (prop_id) {
 	default:
@@ -377,9 +385,8 @@ dmap_mdns_publisher_set_property (GObject * object,
 }
 
 static void
-dmap_mdns_publisher_get_property (GObject * object,
-				  guint prop_id,
-				  GValue * value, GParamSpec * pspec)
+_get_property (GObject * object, guint prop_id, GValue * value,
+               GParamSpec * pspec)
 {
 	switch (prop_id) {
 	default:
@@ -389,9 +396,9 @@ dmap_mdns_publisher_get_property (GObject * object,
 }
 
 static GObject *
-dmap_mdns_publisher_constructor (GType type,
-				 guint n_construct_params,
-				 GObjectConstructParam * construct_params)
+_constructor (GType type,
+              guint n_construct_params,
+              GObjectConstructParam * construct_params)
 {
 	/* This class is a singleton. */
 	static GObject *self = NULL;
@@ -402,10 +409,13 @@ dmap_mdns_publisher_constructor (GType type,
 									 n_construct_params,
 									 construct_params);
 		g_object_add_weak_pointer (self, (gpointer) & self);
-		return self;
+		goto done;
 	}
 
-	return g_object_ref (self);
+	self = g_object_ref (self);
+
+done:
+	return self;
 }
 
 static void
@@ -413,12 +423,12 @@ dmap_mdns_publisher_class_init (DmapMdnsPublisherClass * klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-	object_class->constructor = dmap_mdns_publisher_constructor;
-	object_class->finalize = dmap_mdns_publisher_finalize;
-	object_class->get_property = dmap_mdns_publisher_get_property;
-	object_class->set_property = dmap_mdns_publisher_set_property;
+	object_class->constructor  = _constructor;
+	object_class->finalize     = _finalize;
+	object_class->get_property = _get_property;
+	object_class->set_property = _set_property;
 
-	signals[PUBLISHED] =
+	_signals[PUBLISHED] =
 		g_signal_new ("published",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
@@ -426,7 +436,7 @@ dmap_mdns_publisher_class_init (DmapMdnsPublisherClass * klass)
 					       published), NULL, NULL,
 			      g_cclosure_marshal_VOID__STRING, G_TYPE_NONE, 1,
 			      G_TYPE_STRING);
-	signals[NAME_COLLISION] =
+	_signals[NAME_COLLISION] =
 		g_signal_new ("name-collision",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
@@ -449,12 +459,12 @@ dmap_mdns_publisher_init (DmapMdnsPublisher * publisher)
 }
 
 static void
-dmap_mdns_publisher_finalize (GObject * object)
+_finalize (GObject * object)
 {
 	DmapMdnsPublisher *publisher;
 
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (IS_DMAP_MDNS_PUBLISHER (object));
+	g_assert(NULL != object);
+	g_assert(IS_DMAP_MDNS_PUBLISHER (object));
 
 	publisher = DMAP_MDNS_PUBLISHER (object);
 
@@ -475,11 +485,11 @@ dmap_mdns_publisher_finalize (GObject * object)
 	 * avahi_client_free (publisher->priv->client);
 	 */
 
-	g_slist_foreach (publisher->priv->service, (GFunc) free_service,
+	g_slist_foreach (publisher->priv->service, (GFunc) _free_service,
 			 NULL);
 	g_slist_free (publisher->priv->service);
 
-	publisher_object = NULL;
+	_publisher_object = NULL;
 
 	G_OBJECT_CLASS (dmap_mdns_publisher_parent_class)->finalize (object);
 }
@@ -487,14 +497,14 @@ dmap_mdns_publisher_finalize (GObject * object)
 DmapMdnsPublisher *
 dmap_mdns_publisher_new (void)
 {
-	if (publisher_object) {
-		g_object_ref (publisher_object);
+	if (_publisher_object) {
+		g_object_ref (_publisher_object);
 	} else {
-		publisher_object =
+		_publisher_object =
 			g_object_new (DMAP_TYPE_MDNS_PUBLISHER, NULL);
-		g_object_add_weak_pointer (publisher_object,
-					   (gpointer *) & publisher_object);
+		g_object_add_weak_pointer (_publisher_object,
+					   (gpointer *) &_publisher_object);
 	}
 
-	return DMAP_MDNS_PUBLISHER (publisher_object);
+	return DMAP_MDNS_PUBLISHER (_publisher_object);
 }
