@@ -23,6 +23,7 @@
 #include "config.h"
 
 #include <time.h>
+#include <stdarg.h>
 #include <string.h>
 #include <stdlib.h>
 
@@ -38,7 +39,6 @@
 #define DMAP_VERSION 2.0
 #define DAAP_VERSION 3.0
 #define DMAP_TIMEOUT 1800
-#define DMAP_STATUS_OK 200
 
 enum
 {
@@ -54,6 +54,14 @@ enum
 	PROP_TXT_RECORDS
 };
 
+enum
+{
+	ERROR,
+	LAST_SIGNAL
+};
+
+static guint _signals[LAST_SIGNAL] = { 0, };
+
 struct DmapSharePrivate
 {
 	gchar *name;
@@ -220,14 +228,14 @@ _ctrl_int_adapter (SoupServer * server,
 }
 
 gboolean
-dmap_share_serve (DmapShare *share)
+dmap_share_serve (DmapShare *share, GError **error)
 {
 	guint desired_port = DMAP_SHARE_GET_CLASS (share)->get_desired_port (share);
 	gboolean password_required, ok = FALSE;
-	GError *error = NULL;
 	GSList *listening_uri_list;
 	SoupURI *listening_uri;
 	gboolean ret;
+	GError *error2 = NULL;
 
 	share->priv->server = soup_server_new (NULL, NULL);
 
@@ -279,20 +287,18 @@ dmap_share_serve (DmapShare *share)
 				 (SoupServerCallback) _ctrl_int_adapter,
 				 share, NULL);
 
-	ret = soup_server_listen_all (share->priv->server, desired_port, 0, &error);
-
+	ret = soup_server_listen_all (share->priv->server, desired_port, 0, &error2);
 	if (ret == FALSE) {
 		g_debug ("Unable to start music sharing server on port %d: %s. "
-			 "Trying any open IPv6 port", desired_port, error->message);
-		g_clear_error (&error);
+			 "Trying any open IPv6 port", desired_port, error2->message);
+		g_error_free(error2);
 
 		ret = soup_server_listen_all (share->priv->server, SOUP_ADDRESS_ANY_PORT,
-					      0, &error);
+					      0, error);
 	}
 
 	listening_uri_list = soup_server_get_uris (share->priv->server);
 	if (ret == FALSE || listening_uri_list == NULL) {
-		g_warning ("Unable to start music sharing server on any port.");
 		goto done;
 	}
 
@@ -316,6 +322,9 @@ dmap_share_serve (DmapShare *share)
 	ok = TRUE;
 
 done:
+	g_assert((!ok && (NULL == error || NULL != *error))
+	      || ( ok && (NULL == error || NULL == *error)));
+
 	return ok;
 }
 
@@ -342,36 +351,25 @@ _server_stop (DmapShare * share)
 }
 
 gboolean
-dmap_share_publish (DmapShare * share)
+dmap_share_publish (DmapShare *share, GError **error)
 {
-	GError *error;
 	gboolean ok;
 	gboolean password_required;
 
 	password_required =
 		(share->priv->auth_method != DMAP_SHARE_AUTH_METHOD_NONE);
 
-	error = NULL;
 	ok = dmap_mdns_publisher_publish (share->priv->publisher,
 	                                  share->priv->name,
 	                                  share->priv->port,
 	                                  DMAP_SHARE_GET_CLASS (share)->
 	                                  get_type_of_service (share),
 	                                  password_required,
-	                                  share->priv->txt_records, &error);
+	                                  share->priv->txt_records, error);
 
 	if (ok == FALSE) {
-		if (error != NULL) {
-			g_warning
-				("Unable to notify network of media sharing: %s",
-				 error->message);
-			g_error_free (error);
-		} else {
-			g_warning
-				("Unable to notify network of media sharing");
-		}
-	}
 		goto done;
+	}
 
 	g_debug ("Published DMAP server information to mdns");
 
@@ -408,15 +406,19 @@ done:
 static void
 _restart (DmapShare * share)
 {
+	GError *error = NULL;
 	gboolean res;
 
 	_server_stop (share);
-	res = dmap_share_serve (share);
-	if (res) {
-		/* To update information just publish again */
-		dmap_share_publish (share);
-	} else {
+	res = dmap_share_serve (share, &error);
+	if (NULL != error) {
+		g_signal_emit (share, _signals[ERROR], 0, error);
 		_publish_stop (share);
+	} else {
+		g_assert(FALSE != res);
+
+		/* To update information just publish again */
+		dmap_share_publish (share, NULL);
 	}
 }
 
@@ -649,7 +651,7 @@ dmap_share_class_init (DmapShareClass * klass)
 
 	g_object_class_install_property (object_class,
 					 PROP_REVISION_NUMBER,
-					 g_param_spec_uint ("revision_number",
+					 g_param_spec_uint ("revision-number",
 							    "Revision number",
 							    "Revision number",
 							    0,
@@ -659,7 +661,7 @@ dmap_share_class_init (DmapShareClass * klass)
 
 	g_object_class_install_property (object_class,
 					 PROP_AUTH_METHOD,
-					 g_param_spec_uint ("auth_method",
+					 g_param_spec_uint ("auth-method",
 							    "Authentication method",
 							    "Authentication method",
 							    DMAP_SHARE_AUTH_METHOD_NONE,
@@ -703,6 +705,14 @@ dmap_share_class_init (DmapShareClass * klass)
 							     G_PARAM_READWRITE));
 
 	g_type_class_add_private (klass, sizeof (DmapSharePrivate));
+
+	_signals[ERROR] =
+		g_signal_new ("error",
+		               G_TYPE_FROM_CLASS (object_class),
+		               G_SIGNAL_RUN_FIRST,
+		               0, NULL, NULL,
+		               g_cclosure_marshal_VOID__POINTER, G_TYPE_NONE, 1,
+		               G_TYPE_POINTER);
 }
 
 static void
@@ -1007,19 +1017,17 @@ dmap_share_content_codes (DmapShare * share,
 
 	g_debug ("Path is %s.", path);
 
-	defs = dmap_content_codes (&num_defs);
+	defs = dmap_structure_content_codes (&num_defs);
 
 	mccr = dmap_structure_add (NULL, DMAP_CC_MCCR);
-	dmap_structure_add (mccr, DMAP_CC_MSTT, (gint32) DMAP_STATUS_OK);
+	dmap_structure_add (mccr, DMAP_CC_MSTT, (gint32) SOUP_STATUS_OK);
 
 	for (i = 0; i < num_defs; i++) {
 		GNode *mdcl;
 
 		mdcl = dmap_structure_add (mccr, DMAP_CC_MDCL);
 		dmap_structure_add (mdcl, DMAP_CC_MCNM,
-				    dmap_content_code_string_as_int32 (defs
-								       [i].
-								       string));
+				    dmap_structure_cc_string_as_int32 (defs[i].string));
 		dmap_structure_add (mdcl, DMAP_CC_MCNA, defs[i].name);
 		dmap_structure_add (mdcl, DMAP_CC_MCTY,
 				    (gint32) defs[i].type);
@@ -1048,7 +1056,7 @@ dmap_share_login (DmapShare * share,
 	session_id = dmap_share_session_id_create (share, context);
 
 	mlog = dmap_structure_add (NULL, DMAP_CC_MLOG);
-	dmap_structure_add (mlog, DMAP_CC_MSTT, (gint32) DMAP_STATUS_OK);
+	dmap_structure_add (mlog, DMAP_CC_MSTT, (gint32) SOUP_STATUS_OK);
 	dmap_structure_add (mlog, DMAP_CC_MLID, session_id);
 
 	dmap_share_message_set_from_dmap_structure (share, message, mlog);
@@ -1103,7 +1111,7 @@ dmap_share_update (DmapShare * share,
 
 		mupd = dmap_structure_add (NULL, DMAP_CC_MUPD);
 		dmap_structure_add (mupd, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (mupd, DMAP_CC_MUSR,
 				    (gint32)
 				    dmap_share_get_revision_number (share));
@@ -1448,8 +1456,20 @@ dmap_share_free_filter (GSList * filter)
 	}
 }
 
-typedef struct
+void
+dmap_share_emit_error(DmapShare *share, gint code, const gchar *format, ...)
 {
+	va_list ap;
+	GError *error;
+
+	va_start(ap, format);
+	error = g_error_new_valist(DMAP_ERROR, code, format, ap);
+	g_signal_emit_by_name(share, "error", error);
+
+	va_end(ap);
+}
+
+typedef struct {
 	gchar *name;
 	gint64 group_id;
 	gchar *artist;
@@ -1653,7 +1673,7 @@ dmap_share_databases (DmapShare * share,
 
 		avdb = dmap_structure_add (NULL, DMAP_CC_AVDB);
 		dmap_structure_add (avdb, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (avdb, DMAP_CC_MUTY, 0);
 		dmap_structure_add (avdb, DMAP_CC_MTCO, (gint32) 1);
 		dmap_structure_add (avdb, DMAP_CC_MRCO, (gint32) 1);
@@ -1716,7 +1736,7 @@ dmap_share_databases (DmapShare * share,
 
 		agal = dmap_structure_add (NULL, DMAP_CC_AGAL);
 		dmap_structure_add (agal, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (agal, DMAP_CC_MUTY, 0);
 
 		num = g_hash_table_size (groups);
@@ -1845,7 +1865,7 @@ dmap_share_databases (DmapShare * share,
 		/* 2: */
 		adbs = dmap_structure_add (NULL, DMAP_CC_ADBS);
 		dmap_structure_add (adbs, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (adbs, DMAP_CC_MUTY, 0);
 		dmap_structure_add (adbs, DMAP_CC_MTCO, (gint32) num_songs);
 		dmap_structure_add (adbs, DMAP_CC_MRCO, (gint32) num_songs);
@@ -1911,7 +1931,7 @@ dmap_share_databases (DmapShare * share,
 
 		aply = dmap_structure_add (NULL, DMAP_CC_APLY);
 		dmap_structure_add (aply, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (aply, DMAP_CC_MUTY, 0);
 		dmap_structure_add (aply, DMAP_CC_MTCO,
 				    (gint32) dmap_container_db_count (share->
@@ -1978,7 +1998,7 @@ dmap_share_databases (DmapShare * share,
 
 		apso = dmap_structure_add (NULL, DMAP_CC_APSO);
 		dmap_structure_add (apso, DMAP_CC_MSTT,
-				    (gint32) DMAP_STATUS_OK);
+				    (gint32) SOUP_STATUS_OK);
 		dmap_structure_add (apso, DMAP_CC_MUTY, 0);
 
 		if (g_ascii_strcasecmp ("/1/items", rest_of_path + 13) == 0) {
