@@ -87,26 +87,22 @@ G_BEGIN_DECLS
  */
 #define DMAP_SHARE_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), \
 				 DMAP_TYPE_SHARE, DmapShareClass))
-#define DMAP_STATUS_OK 200
 typedef struct DmapSharePrivate DmapSharePrivate;
 
-typedef struct
-{
+typedef struct {
 	GObject parent;
 	DmapSharePrivate *priv;
 } DmapShare;
 
 typedef struct DmapMetaDataMap DmapMetaDataMap;
 
-typedef enum
-{
+typedef enum {
 	DMAP_SHARE_AUTH_METHOD_NONE = 0,
 	DMAP_SHARE_AUTH_METHOD_NAME_AND_PASSWORD = 1,
 	DMAP_SHARE_AUTH_METHOD_PASSWORD = 2
 } DmapShareAuthMethod;
 
-typedef struct
-{
+typedef struct {
 	GObjectClass parent;
 
 	/* Pure virtual methods: */
@@ -194,23 +190,25 @@ GType dmap_share_get_type (void);
 /**
  * dmap_share_serve:
  * @share: a #DmapShare instance.
+ * @error: return location for a GError, or NULL.
  *
  * Begin serving the service defined by share. A program will normally also
  * call dmap_share_publish.
  *
- * Returns: TRUE if serving succeeds, else FALSE.
+ * Returns: TRUE if serving succeeds, else FALSE with error set.
  */
-gboolean dmap_share_serve(DmapShare *share);
+gboolean dmap_share_serve(DmapShare *share, GError **error);
 
 /**
  * dmap_share_publish:
  * @share: a #DmapShare instance.
+ * @error: return location for a GError, or NULL.
  *
  * Publish the availability of the given share using mDNS-SD.
  *
  * Returns: TRUE if publishing succeeds, else FALSE.
  */
-gboolean dmap_share_publish(DmapShare *share);
+gboolean dmap_share_publish(DmapShare *share, GError **error);
 
 /**
  * dmap_share_free_filter:
@@ -220,6 +218,15 @@ gboolean dmap_share_publish(DmapShare *share);
  */
 void dmap_share_free_filter (GSList * filter);
 
+/**
+ * dmap_share_emit_error:
+ * @share: a #DmapShare instance.
+ * @code: error code.
+ * @format: printf()-style format for error message
+ * @...: parameters for message format
+ */
+void dmap_share_emit_error(DmapShare *share, gint code, const gchar *format, ...);
+
 #endif /* _DMAP_SHARE_H */
 
 G_END_DECLS
