@@ -51,6 +51,12 @@ dmap_sharing_default_share_name ()
 	return g_strdup_printf ("%s's Media (libdmapsharing test)", real_name);
 }
 
+static void
+error_cb(DmapShare *share, GError *error, gpointer user_data)
+{
+	g_error("%s", error->message);
+}
+
 static void
 create_share (guint conn_type)
 {
@@ -63,6 +69,8 @@ create_share (guint conn_type)
 	DmapRecordFactory *factory;
 	DmapRecord *record;
 	DmapShare *share = NULL;
+	GError *error = NULL;
+	gboolean ok;
 	DmapDb *db;
 
 	if (conn_type == DAAP) { 
@@ -72,9 +80,9 @@ create_share (guint conn_type)
 		factory = DMAP_RECORD_FACTORY (test_dmap_image_record_factory_new ());
 	}
 
-	record = DMAP_RECORD (dmap_record_factory_create (factory, NULL));
+	record = DMAP_RECORD (dmap_record_factory_create (factory, NULL, NULL));
 	db = DMAP_DB (test_dmap_db_new ());
-	dmap_db_add (db, record);
+	dmap_db_add (db, record, NULL);
 	g_object_unref (record);
 
 	g_warning ("initialize DAAP sharing");
@@ -84,7 +92,7 @@ create_share (guint conn_type)
                                                        NULL,
                                                        db,
                                                        dmap_container_db,
-NULL));
+		                                       NULL));
 	} else {
 		share = DMAP_SHARE (dmap_image_share_new (name,
                                                           NULL,
@@ -95,6 +103,18 @@ NULL));
 
 	g_assert (NULL != share);
 
+	g_signal_connect(share, "error", G_CALLBACK(error_cb), NULL);
+
+	ok = dmap_share_serve(share, &error);
+	if (!ok) {
+		g_error("Error starting server: %s", error->message);
+	}
+
+	ok = dmap_share_publish(share, &error);
+	if (!ok) {
+		g_error("Error publishing server: %s", error->message);
+	}
+
 	g_free (name);
 }
 
